"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, account_id: str, bucket: str) -> None:
    r"""
    **Autogenerated function**

     This action deletes an Amazon S3 on Outposts bucket policy. To delete an S3 bucket policy, see DeleteBucketPolicy in the Amazon S3 API Reference.   This implementation of the DELETE action uses the policy subresource to delete the policy of a specified Amazon S3 on Outposts bucket. If you are using an identity other than the root user of the account that owns the bucket, the calling identity must have the s3-outposts:DeleteBucketPolicy permissions on the specified Outposts bucket and belong to the bucket owner's account to use this action. For more information, see Using Amazon S3 on Outposts in Amazon S3 User Guide. If you don't have DeleteBucketPolicy permissions, Amazon S3 returns a 403 Access Denied error. If you have the correct permissions, but you're not using an identity that belongs to the bucket owner's account, Amazon S3 returns a 405 Method Not Allowed error.   As a security precaution, the root user of the account that owns a bucket can always use this action, even if the policy explicitly denies the root user the ability to perform this action.  For more information about bucket policies, see Using Bucket Policies and User Policies.  All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to DeleteBucketPolicy:    GetBucketPolicy     PutBucketPolicy

    Args:
        account_id(str): The account ID of the Outposts bucket.
        bucket(str): Specifies the bucket. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.policy.delete(
                ctx, account_id=value, bucket=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.policy.delete account_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_bucket_policy",
        op_kwargs={"AccountId": account_id, "Bucket": bucket},
    )


async def get(hub, ctx, account_id: str, bucket: str) -> Dict:
    r"""
    **Autogenerated function**

     This action gets a bucket policy for an Amazon S3 on Outposts bucket. To get a policy for an S3 bucket, see GetBucketPolicy in the Amazon S3 API Reference.   Returns the policy of a specified Outposts bucket. For more information, see Using Amazon S3 on Outposts in the Amazon S3 User Guide. If you are using an identity other than the root user of the account that owns the bucket, the calling identity must have the GetBucketPolicy permissions on the specified bucket and belong to the bucket owner's account in order to use this action. Only users from Outposts bucket owner account with the right permissions can perform actions on an Outposts bucket. If you don't have s3-outposts:GetBucketPolicy permissions or you're not using an identity that belongs to the bucket owner's account, Amazon S3 returns a 403 Access Denied error.  As a security precaution, the root user of the account that owns a bucket can always use this action, even if the policy explicitly denies the root user the ability to perform this action.  For more information about bucket policies, see Using Bucket Policies and User Policies. All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to GetBucketPolicy:    GetObject     PutBucketPolicy     DeleteBucketPolicy

    Args:
        account_id(str): The account ID of the Outposts bucket.
        bucket(str): Specifies the bucket. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.policy.get(ctx, account_id=value, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.policy.get account_id=value, bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_bucket_policy",
        op_kwargs={"AccountId": account_id, "Bucket": bucket},
    )


async def put(
    hub,
    ctx,
    account_id: str,
    bucket: str,
    policy: str,
    confirm_remove_self_bucket_access: bool = None,
) -> None:
    r"""
    **Autogenerated function**

     This action puts a bucket policy to an Amazon S3 on Outposts bucket. To put a policy on an S3 bucket, see PutBucketPolicy in the Amazon S3 API Reference.   Applies an Amazon S3 bucket policy to an Outposts bucket. For more information, see Using Amazon S3 on Outposts in the Amazon S3 User Guide. If you are using an identity other than the root user of the account that owns the Outposts bucket, the calling identity must have the PutBucketPolicy permissions on the specified Outposts bucket and belong to the bucket owner's account in order to use this action. If you don't have PutBucketPolicy permissions, Amazon S3 returns a 403 Access Denied error. If you have the correct permissions, but you're not using an identity that belongs to the bucket owner's account, Amazon S3 returns a 405 Method Not Allowed error.   As a security precaution, the root user of the account that owns a bucket can always use this action, even if the policy explicitly denies the root user the ability to perform this action.   For more information about bucket policies, see Using Bucket Policies and User Policies. All Amazon S3 on Outposts REST API requests for this action require an additional parameter of x-amz-outpost-id to be passed with the request and an S3 on Outposts endpoint hostname prefix instead of s3-control. For an example of the request syntax for Amazon S3 on Outposts that uses the S3 on Outposts endpoint hostname prefix and the x-amz-outpost-id derived using the access point ARN, see the Examples section. The following actions are related to PutBucketPolicy:    GetBucketPolicy     DeleteBucketPolicy

    Args:
        account_id(str): The account ID of the Outposts bucket.
        bucket(str): Specifies the bucket. For using this parameter with Amazon S3 on Outposts with the REST API, you must specify the name and the x-amz-outpost-id as well. For using this parameter with S3 on Outposts with the Amazon Web Services SDK and CLI, you must specify the ARN of the bucket accessed in the format arn:aws:s3-outposts:<Region>:<account-id>:outpost/<outpost-id>/bucket/<my-bucket-name>. For example, to access the bucket reports through outpost my-outpost owned by account 123456789012 in Region us-west-2, use the URL encoding of arn:aws:s3-outposts:us-west-2:123456789012:outpost/my-outpost/bucket/reports. The value must be URL encoded. .
        confirm_remove_self_bucket_access(bool, optional): Set this parameter to true to confirm that you want to remove your permissions to change this bucket policy in the future.  This is not supported by Amazon S3 on Outposts buckets. . Defaults to None.
        policy(str): The bucket policy as a JSON document.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.bucket.policy.put(
                ctx, account_id=value, bucket=value, policy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.bucket.policy.put account_id=value, bucket=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="put_bucket_policy",
        op_kwargs={
            "AccountId": account_id,
            "Bucket": bucket,
            "ConfirmRemoveSelfBucketAccess": confirm_remove_self_bucket_access,
            "Policy": policy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    client_cidr_block: str,
    server_certificate_arn: str,
    authentication_options: List,
    connection_log_options: Dict,
    dns_servers: List = None,
    transport_protocol: str = None,
    vpn_port: int = None,
    description: str = None,
    split_tunnel: bool = None,
    dry_run: bool = None,
    client_token: str = None,
    tag_specifications: List = None,
    security_group_ids: List = None,
    vpc_id: str = None,
    self_service_portal: str = None,
    client_connect_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Client VPN endpoint. A Client VPN endpoint is the resource you create and configure to enable and manage client VPN sessions. It is the destination endpoint at which all client VPN sessions are terminated.

    Args:
        client_cidr_block(str): The IPv4 address range, in CIDR notation, from which to assign client IP addresses. The address range cannot overlap with the local CIDR of the VPC in which the associated subnet is located, or the routes that you add manually. The address range cannot be changed after the Client VPN endpoint has been created. The CIDR block should be /22 or greater.
        server_certificate_arn(str): The ARN of the server certificate. For more information, see the AWS Certificate Manager User Guide.
        authentication_options(List): Information about the authentication method to be used to authenticate clients.
        connection_log_options(Dict): Information about the client connection logging options. If you enable client connection logging, data about client connections is sent to a Cloudwatch Logs log stream. The following information is logged:   Client connection requests   Client connection results (successful and unsuccessful)   Reasons for unsuccessful client connection requests   Client connection termination time  .
        dns_servers(List, optional): Information about the DNS servers to be used for DNS resolution. A Client VPN endpoint can have up to two DNS servers. If no DNS server is specified, the DNS address configured on the device is used for the DNS server. Defaults to None.
        transport_protocol(str, optional): The transport protocol to be used by the VPN session. Default value: udp . Defaults to None.
        vpn_port(int, optional): The port number to assign to the Client VPN endpoint for TCP and UDP traffic. Valid Values: 443 | 1194  Default Value: 443 . Defaults to None.
        description(str, optional): A brief description of the Client VPN endpoint. Defaults to None.
        split_tunnel(bool, optional): Indicates whether split-tunnel is enabled on the AWS Client VPN endpoint. By default, split-tunnel on a VPN endpoint is disabled. For information about split-tunnel VPN endpoints, see Split-Tunnel AWS Client VPN Endpoint in the AWS Client VPN Administrator Guide. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the Client VPN endpoint during creation. Defaults to None.
        security_group_ids(List, optional): The IDs of one or more security groups to apply to the target network. You must also specify the ID of the VPC that contains the security groups. Defaults to None.
        vpc_id(str, optional): The ID of the VPC to associate with the Client VPN endpoint. If no security group IDs are specified in the request, the default security group for the VPC is applied. Defaults to None.
        self_service_portal(str, optional): Specify whether to enable the self-service portal for the Client VPN endpoint. Default Value: enabled . Defaults to None.
        client_connect_options(Dict, optional): The options for managing connection authorization for new client connections. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.endpoint.create(
                ctx,
                client_cidr_block=value,
                server_certificate_arn=value,
                authentication_options=value,
                connection_log_options=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.endpoint.create client_cidr_block=value, server_certificate_arn=value, authentication_options=value, connection_log_options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_client_vpn_endpoint",
        op_kwargs={
            "ClientCidrBlock": client_cidr_block,
            "ServerCertificateArn": server_certificate_arn,
            "AuthenticationOptions": authentication_options,
            "ConnectionLogOptions": connection_log_options,
            "DnsServers": dns_servers,
            "TransportProtocol": transport_protocol,
            "VpnPort": vpn_port,
            "Description": description,
            "SplitTunnel": split_tunnel,
            "DryRun": dry_run,
            "ClientToken": client_token,
            "TagSpecifications": tag_specifications,
            "SecurityGroupIds": security_group_ids,
            "VpcId": vpc_id,
            "SelfServicePortal": self_service_portal,
            "ClientConnectOptions": client_connect_options,
        },
    )


async def delete(hub, ctx, client_vpn_endpoint_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified Client VPN endpoint. You must disassociate all target networks before you can delete a Client VPN endpoint.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN to be deleted.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.endpoint.delete(
                ctx, client_vpn_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.endpoint.delete client_vpn_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_client_vpn_endpoint",
        op_kwargs={"ClientVpnEndpointId": client_vpn_endpoint_id, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    client_vpn_endpoint_ids: List = None,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more Client VPN endpoints in the account.

    Args:
        client_vpn_endpoint_ids(List, optional): The ID of the Client VPN endpoint. Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.
        filters(List, optional): One or more filters. Filter names and values are case-sensitive.    endpoint-id - The ID of the Client VPN endpoint.    transport-protocol - The transport protocol (tcp | udp).  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.endpoint.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.endpoint.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_client_vpn_endpoints",
        op_kwargs={
            "ClientVpnEndpointIds": client_vpn_endpoint_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
            "DryRun": dry_run,
        },
    )


async def modify(
    hub,
    ctx,
    client_vpn_endpoint_id: str,
    server_certificate_arn: str = None,
    connection_log_options: Dict = None,
    dns_servers: Dict = None,
    vpn_port: int = None,
    description: str = None,
    split_tunnel: bool = None,
    dry_run: bool = None,
    security_group_ids: List = None,
    vpc_id: str = None,
    self_service_portal: str = None,
    client_connect_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified Client VPN endpoint. Modifying the DNS server resets existing client connections.

    Args:
        client_vpn_endpoint_id(str): The ID of the Client VPN endpoint to modify.
        server_certificate_arn(str, optional): The ARN of the server certificate to be used. The server certificate must be provisioned in AWS Certificate Manager (ACM). Defaults to None.
        connection_log_options(Dict, optional): Information about the client connection logging options. If you enable client connection logging, data about client connections is sent to a Cloudwatch Logs log stream. The following information is logged:   Client connection requests   Client connection results (successful and unsuccessful)   Reasons for unsuccessful client connection requests   Client connection termination time  . Defaults to None.
        dns_servers(Dict, optional): Information about the DNS servers to be used by Client VPN connections. A Client VPN endpoint can have up to two DNS servers. Defaults to None.
        vpn_port(int, optional): The port number to assign to the Client VPN endpoint for TCP and UDP traffic. Valid Values: 443 | 1194  Default Value: 443 . Defaults to None.
        description(str, optional): A brief description of the Client VPN endpoint. Defaults to None.
        split_tunnel(bool, optional): Indicates whether the VPN is split-tunnel. For information about split-tunnel VPN endpoints, see Split-Tunnel AWS Client VPN Endpoint in the AWS Client VPN Administrator Guide. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        security_group_ids(List, optional): The IDs of one or more security groups to apply to the target network. Defaults to None.
        vpc_id(str, optional): The ID of the VPC to associate with the Client VPN endpoint. Defaults to None.
        self_service_portal(str, optional): Specify whether to enable the self-service portal for the Client VPN endpoint. Defaults to None.
        client_connect_options(Dict, optional): The options for managing connection authorization for new client connections. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.client_vpn.endpoint.modify(
                ctx, client_vpn_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.client_vpn.endpoint.modify client_vpn_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_client_vpn_endpoint",
        op_kwargs={
            "ClientVpnEndpointId": client_vpn_endpoint_id,
            "ServerCertificateArn": server_certificate_arn,
            "ConnectionLogOptions": connection_log_options,
            "DnsServers": dns_servers,
            "VpnPort": vpn_port,
            "Description": description,
            "SplitTunnel": split_tunnel,
            "DryRun": dry_run,
            "SecurityGroupIds": security_group_ids,
            "VpcId": vpc_id,
            "SelfServicePortal": self_service_portal,
            "ClientConnectOptions": client_connect_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    connector_profile_name: str,
    connector_type: str,
    connection_mode: str,
    connector_profile_config: Dict,
    kms_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new connector profile associated with your AWS account. There is a soft quota of 100 connector profiles per AWS account. If you need more connector profiles than this quota allows, you can submit a request to the Amazon AppFlow team through the Amazon AppFlow support channel.

    Args:
        connector_profile_name(str):  The name of the connector profile. The name is unique for each ConnectorProfile in your AWS account. .
        kms_arn(str, optional):  The ARN (Amazon Resource Name) of the Key Management Service (KMS) key you provide for encryption. This is required if you do not want to use the Amazon AppFlow-managed KMS key. If you don't provide anything here, Amazon AppFlow uses the Amazon AppFlow-managed KMS key. . Defaults to None.
        connector_type(str):  The type of connector, such as Salesforce, Amplitude, and so on. .
        connection_mode(str):  Indicates the connection mode and specifies whether it is public or private. Private flows use AWS PrivateLink to route data over AWS infrastructure without exposing it to the public internet. .
        connector_profile_config(Dict):  Defines the connector-specific configuration and credentials. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.connector.profile.create(
                ctx,
                connector_profile_name=value,
                connector_type=value,
                connection_mode=value,
                connector_profile_config=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.connector.profile.create connector_profile_name=value, connector_type=value, connection_mode=value, connector_profile_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="create_connector_profile",
        op_kwargs={
            "connectorProfileName": connector_profile_name,
            "kmsArn": kms_arn,
            "connectorType": connector_type,
            "connectionMode": connection_mode,
            "connectorProfileConfig": connector_profile_config,
        },
    )


async def delete(
    hub, ctx, connector_profile_name: str, force_delete: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

     Enables you to delete an existing connector profile.

    Args:
        connector_profile_name(str):  The name of the connector profile. The name is unique for each ConnectorProfile in your account. .
        force_delete(bool, optional):  Indicates whether Amazon AppFlow should delete the profile, even if it is currently in use in one or more flows. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.connector.profile.delete(
                ctx, connector_profile_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.connector.profile.delete connector_profile_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="delete_connector_profile",
        op_kwargs={
            "connectorProfileName": connector_profile_name,
            "forceDelete": force_delete,
        },
    )


async def describe_all(
    hub,
    ctx,
    connector_profile_names: List = None,
    connector_type: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of connector-profile details matching the provided connector-profile names and connector-types. Both input lists are optional, and you can use them to filter the result.  If no names or connector-types are provided, returns all connector profiles in a paginated form. If there is no match, this operation returns an empty list.

    Args:
        connector_profile_names(List, optional):  The name of the connector profile. The name is unique for each ConnectorProfile in the AWS account. . Defaults to None.
        connector_type(str, optional):  The type of connector, such as Salesforce, Amplitude, and so on. . Defaults to None.
        max_results(int, optional):  Specifies the maximum number of items that should be returned in the result set. The default for maxResults is 20 (for all paginated API operations). . Defaults to None.
        next_token(str, optional):  The pagination token for the next page of data. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.connector.profile.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.connector.profile.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="describe_connector_profiles",
        op_kwargs={
            "connectorProfileNames": connector_profile_names,
            "connectorType": connector_type,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    connector_profile_name: str,
    connection_mode: str,
    connector_profile_config: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a given connector profile associated with your account.

    Args:
        connector_profile_name(str):  The name of the connector profile and is unique for each ConnectorProfile in the AWS Account. .
        connection_mode(str):  Indicates the connection mode and if it is public or private. .
        connector_profile_config(Dict):  Defines the connector-specific profile configuration and credentials. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appflow.connector.profile.update(
                ctx,
                connector_profile_name=value,
                connection_mode=value,
                connector_profile_config=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appflow.connector.profile.update connector_profile_name=value, connection_mode=value, connector_profile_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appflow",
        operation="update_connector_profile",
        op_kwargs={
            "connectorProfileName": connector_profile_name,
            "connectionMode": connection_mode,
            "connectorProfileConfig": connector_profile_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def add(hub, ctx, resource_name: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds metadata tags to an Amazon Neptune resource. These tags can also be used with cost allocation reporting to track cost associated with Amazon Neptune resources, or used in a Condition statement in an IAM policy for Amazon Neptune.

    Args:
        resource_name(str): The Amazon Neptune resource that the tags are added to. This value is an Amazon Resource Name (ARN). For information about creating an ARN, see  Constructing an Amazon Resource Name (ARN).
        tags(List): The tags to be assigned to the Amazon Neptune resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.tags.to_resource.add(
                ctx, resource_name=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.tags.to_resource.add resource_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="add_tags_to_resource",
        op_kwargs={"ResourceName": resource_name, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def start(hub, ctx, config_rule_names: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Runs an on-demand evaluation for the specified AWS Config rules against the last known configuration state of the resources. Use StartConfigRulesEvaluation when you want to test that a rule you updated is working as expected. StartConfigRulesEvaluation does not re-record the latest configuration state for your resources. It re-runs an evaluation against the last known state of your resources.  You can specify up to 25 AWS Config rules per request.  An existing StartConfigRulesEvaluation call for the specified rules must complete before you can call the API again. If you chose to have AWS Config stream to an Amazon SNS topic, you will receive a ConfigRuleEvaluationStarted notification when the evaluation starts.  You don't need to call the StartConfigRulesEvaluation API to run an evaluation for a new rule. When you create a rule, AWS Config evaluates your resources against the rule automatically.   The StartConfigRulesEvaluation API is useful if you want to run on-demand evaluations, such as the following example:   You have a custom rule that evaluates your IAM resources every 24 hours.   You update your Lambda function to add additional conditions to your rule.   Instead of waiting for the next periodic evaluation, you call the StartConfigRulesEvaluation API.   AWS Config invokes your Lambda function and evaluates your IAM resources.   Your custom rule will still run periodic evaluations every 24 hours.

    Args:
        config_rule_names(List, optional): The list of names of AWS Config rules that you want to run evaluations for. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.config.rule.evaluation.init.start(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.config.rule.evaluation.init.start
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="start_config_rules_evaluation",
        op_kwargs={"ConfigRuleNames": config_rule_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    aws_account_id: str,
    folder_id: str,
    name: str = None,
    folder_type: str = None,
    parent_folder_arn: str = None,
    permissions: List = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an empty shared folder.

    Args:
        aws_account_id(str): The AWS Account ID.
        folder_id(str): The folder ID.
        name(str, optional): The name of the folder. Defaults to None.
        folder_type(str, optional): The type of folder. By default, folderType is SHARED. Defaults to None.
        parent_folder_arn(str, optional): The Amazon Resource Name (ARN) for the parent folder.  ParentFolderArn can be null. An empty parentFolderArn creates a root-level folder. Defaults to None.
        permissions(List, optional): A structure that describes the principals and the resource-level permissions of a folder. To specify no permissions, omit Permissions. Defaults to None.
        tags(List, optional): Tags for the folder. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.folder.init.create(
                ctx, aws_account_id=value, folder_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.folder.init.create aws_account_id=value, folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="create_folder",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "FolderId": folder_id,
            "Name": name,
            "FolderType": folder_type,
            "ParentFolderArn": parent_folder_arn,
            "Permissions": permissions,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, aws_account_id: str, folder_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an empty folder.

    Args:
        aws_account_id(str): The AWS Account ID for the folder.
        folder_id(str): The folder ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.folder.init.delete(
                ctx, aws_account_id=value, folder_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.folder.init.delete aws_account_id=value, folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="delete_folder",
        op_kwargs={"AwsAccountId": aws_account_id, "FolderId": folder_id},
    )


async def describe(hub, ctx, aws_account_id: str, folder_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a folder.

    Args:
        aws_account_id(str): The AWS account ID.
        folder_id(str): The folder ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.folder.init.describe(
                ctx, aws_account_id=value, folder_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.folder.init.describe aws_account_id=value, folder_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="describe_folder",
        op_kwargs={"AwsAccountId": aws_account_id, "FolderId": folder_id},
    )


async def list_all(
    hub, ctx, aws_account_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all folders in an account.

    Args:
        aws_account_id(str): The AWS account ID.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.folder.init.list_all(ctx, aws_account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.folder.init.list_all aws_account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_folders",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def search(
    hub,
    ctx,
    aws_account_id: str,
    filters: List,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches the subfolders in a folder.

    Args:
        aws_account_id(str): The AWS account ID.
        filters(List): The filters to apply to the search. Currently, you can search only by the parent folder ARN. For example, "Filters": [ { "Name": "PARENT_FOLDER_ARN", "Operator": "StringEquals", "Value": "arn:aws:quicksight:us-east-1:1:folder/folderId" } ].
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.folder.init.search(
                ctx, aws_account_id=value, filters=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.folder.init.search aws_account_id=value, filters=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="search_folders",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "Filters": filters,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(hub, ctx, aws_account_id: str, folder_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the name of a folder.

    Args:
        aws_account_id(str): The AWS account ID.
        folder_id(str): The folder ID.
        name(str): The name of the folder.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.folder.init.update(
                ctx, aws_account_id=value, folder_id=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.folder.init.update aws_account_id=value, folder_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="update_folder",
        op_kwargs={"AwsAccountId": aws_account_id, "FolderId": folder_id, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    feature_group_name: str,
    record_identifier_feature_name: str,
    event_time_feature_name: str,
    feature_definitions: List,
    online_store_config: Dict = None,
    offline_store_config: Dict = None,
    role_arn: str = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a new FeatureGroup. A FeatureGroup is a group of Features defined in the FeatureStore to describe a Record.  The FeatureGroup defines the schema and features contained in the FeatureGroup. A FeatureGroup definition is composed of a list of Features, a RecordIdentifierFeatureName, an EventTimeFeatureName and configurations for its OnlineStore and OfflineStore. Check Amazon Web Services service quotas to see the FeatureGroups quota for your Amazon Web Services account.  You must include at least one of OnlineStoreConfig and OfflineStoreConfig to create a FeatureGroup.

    Args:
        feature_group_name(str): The name of the FeatureGroup. The name must be unique within an Amazon Web Services Region in an Amazon Web Services account. The name:   Must start and end with an alphanumeric character.   Can only contain alphanumeric character and hyphens. Spaces are not allowed.   .
        record_identifier_feature_name(str): The name of the Feature whose value uniquely identifies a Record defined in the FeatureStore. Only the latest record per identifier value will be stored in the OnlineStore. RecordIdentifierFeatureName must be one of feature definitions' names. You use the RecordIdentifierFeatureName to access data in a FeatureStore. This name:   Must start and end with an alphanumeric character.   Can only contains alphanumeric characters, hyphens, underscores. Spaces are not allowed.   .
        event_time_feature_name(str): The name of the feature that stores the EventTime of a Record in a FeatureGroup. An EventTime is a point in time when a new event occurs that corresponds to the creation or update of a Record in a FeatureGroup. All Records in the FeatureGroup must have a corresponding EventTime. An EventTime can be a String or Fractional.     Fractional: EventTime feature values must be a Unix timestamp in seconds.    String: EventTime feature values must be an ISO-8601 string in the format. The following formats are supported yyyy-MM-dd'T'HH:mm:ssZ and yyyy-MM-dd'T'HH:mm:ss.SSSZ where yyyy, MM, and dd represent the year, month, and day respectively and HH, mm, ss, and if applicable, SSS represent the hour, month, second and milliseconds respsectively. 'T' and Z are constants.  .
        feature_definitions(List): A list of Feature names and types. Name and Type is compulsory per Feature.  Valid feature FeatureTypes are Integral, Fractional and String.  FeatureNames cannot be any of the following: is_deleted, write_time, api_invocation_time  You can create up to 2,500 FeatureDefinitions per FeatureGroup.
        online_store_config(Dict, optional): You can turn the OnlineStore on or off by specifying True for the EnableOnlineStore flag in OnlineStoreConfig; the default value is False. You can also include an Amazon Web Services KMS key ID (KMSKeyId) for at-rest encryption of the OnlineStore. Defaults to None.
        offline_store_config(Dict, optional): Use this to configure an OfflineFeatureStore. This parameter allows you to specify:   The Amazon Simple Storage Service (Amazon S3) location of an OfflineStore.   A configuration for an Amazon Web Services Glue or Amazon Web Services Hive data cataolgue.    An KMS encryption key to encrypt the Amazon S3 location used for OfflineStore.   To learn more about this parameter, see OfflineStoreConfig. Defaults to None.
        role_arn(str, optional): The Amazon Resource Name (ARN) of the IAM execution role used to persist data into the OfflineStore if an OfflineStoreConfig is provided. Defaults to None.
        description(str, optional): A free-form description of a FeatureGroup. Defaults to None.
        tags(List, optional): Tags used to identify Features in each FeatureGroup. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.feature_group.create(
                ctx,
                feature_group_name=value,
                record_identifier_feature_name=value,
                event_time_feature_name=value,
                feature_definitions=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.feature_group.create feature_group_name=value, record_identifier_feature_name=value, event_time_feature_name=value, feature_definitions=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_feature_group",
        op_kwargs={
            "FeatureGroupName": feature_group_name,
            "RecordIdentifierFeatureName": record_identifier_feature_name,
            "EventTimeFeatureName": event_time_feature_name,
            "FeatureDefinitions": feature_definitions,
            "OnlineStoreConfig": online_store_config,
            "OfflineStoreConfig": offline_store_config,
            "RoleArn": role_arn,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, feature_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Delete the FeatureGroup and any data that was written to the OnlineStore of the FeatureGroup. Data cannot be accessed from the OnlineStore immediately after DeleteFeatureGroup is called.  Data written into the OfflineStore will not be deleted. The Amazon Web Services Glue database and tables that are automatically created for your OfflineStore are not deleted.

    Args:
        feature_group_name(str): The name of the FeatureGroup you want to delete. The name must be unique within an Amazon Web Services Region in an Amazon Web Services account. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.feature_group.delete(ctx, feature_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.feature_group.delete feature_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_feature_group",
        op_kwargs={"FeatureGroupName": feature_group_name},
    )


async def describe(hub, ctx, feature_group_name: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Use this operation to describe a FeatureGroup. The response includes information on the creation time, FeatureGroup name, the unique identifier for each FeatureGroup, and more.

    Args:
        feature_group_name(str): The name of the FeatureGroup you want described. .
        next_token(str, optional): A token to resume pagination of the list of Features (FeatureDefinitions). 2,500 Features are returned by default. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.feature_group.describe(ctx, feature_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.feature_group.describe feature_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_feature_group",
        op_kwargs={"FeatureGroupName": feature_group_name, "NextToken": next_token},
    )


async def list_all(
    hub,
    ctx,
    name_contains: str = None,
    feature_group_status_equals: str = None,
    offline_store_status_equals: str = None,
    creation_time_after: str = None,
    creation_time_before: str = None,
    sort_order: str = None,
    sort_by: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List FeatureGroups based on given filter and order.

    Args:
        name_contains(str, optional): A string that partially matches one or more FeatureGroups names. Filters FeatureGroups by name. . Defaults to None.
        feature_group_status_equals(str, optional): A FeatureGroup status. Filters by FeatureGroup status. . Defaults to None.
        offline_store_status_equals(str, optional): An OfflineStore status. Filters by OfflineStore status. . Defaults to None.
        creation_time_after(str, optional): Use this parameter to search for FeatureGroupss created after a specific date and time. Defaults to None.
        creation_time_before(str, optional): Use this parameter to search for FeatureGroupss created before a specific date and time. Defaults to None.
        sort_order(str, optional): The order in which feature groups are listed. Defaults to None.
        sort_by(str, optional): The value on which the feature group list is sorted. Defaults to None.
        max_results(int, optional): The maximum number of results returned by ListFeatureGroups. Defaults to None.
        next_token(str, optional): A token to resume pagination of ListFeatureGroups results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.feature_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.feature_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_feature_groups",
        op_kwargs={
            "NameContains": name_contains,
            "FeatureGroupStatusEquals": feature_group_status_equals,
            "OfflineStoreStatusEquals": offline_store_status_equals,
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "SortOrder": sort_order,
            "SortBy": sort_by,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    type_: str = None,
    type_name: str = None,
    arn: str = None,
    max_results: int = None,
    next_token: str = None,
    deprecated_status: str = None,
    publisher_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns summary information about the versions of an extension.

    Args:
        type_(str, optional): The kind of the extension. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        type_name(str, optional): The name of the extension for which you want version summary information. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        arn(str, optional): The Amazon Resource Name (ARN) of the extension for which you want version summary information. Conditional: You must specify either TypeName and Type, or Arn. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned with a single call. If the number of available results exceeds this maximum, the response includes a NextToken value that you can assign to the NextToken request parameter to get the next set of results. Defaults to None.
        next_token(str, optional): If the previous paginated request didn't return all of the remaining results, the response object's NextToken parameter value is set to a token. To retrieve the next set of results, call this action again and assign that token to the request object's NextToken parameter. If there are no remaining results, the previous response object's NextToken parameter is set to null. Defaults to None.
        deprecated_status(str, optional): The deprecation status of the extension versions that you want to get summary information about. Valid values include:    LIVE: The extension version is registered and can be used in CloudFormation operations, dependent on its provisioning behavior and visibility scope.    DEPRECATED: The extension version has been deregistered and can no longer be used in CloudFormation operations.    The default is LIVE. Defaults to None.
        publisher_id(str, optional): The publisher ID of the extension publisher. Extensions published by Amazon are not assigned a publisher ID. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.type_.version.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.type_.version.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="list_type_versions",
        op_kwargs={
            "Type": type_,
            "TypeName": type_name,
            "Arn": arn,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DeprecatedStatus": deprecated_status,
            "PublisherId": publisher_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    instance_arn: str,
    target_id: str,
    target_type: str,
    permission_set_arn: str,
    principal_type: str,
    principal_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Assigns access to a principal for a specified Amazon Web Services account using a specified permission set.  The term principal here refers to a user or group that is defined in Amazon Web Services SSO.   As part of a successful CreateAccountAssignment call, the specified permission set will automatically be provisioned to the account in the form of an IAM policy. That policy is attached to the SSO-created IAM role. If the permission set is subsequently updated, the corresponding IAM policies attached to roles in your accounts will not be updated automatically. In this case, you must call  ProvisionPermissionSet  to make these updates.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        target_id(str): TargetID is an Amazon Web Services account identifier, typically a 10-12 digit string (For example, 123456789012).
        target_type(str): The entity type for which the assignment will be created.
        permission_set_arn(str): The ARN of the permission set that the admin wants to grant the principal access to.
        principal_type(str): The entity type for which the assignment will be created.
        principal_id(str): An identifier for an object in Amazon Web Services SSO, such as a user or group. PrincipalIds are GUIDs (For example, f81d4fae-7dec-11d0-a765-00a0c91e6bf6). For more information about PrincipalIds in Amazon Web Services SSO, see the Amazon Web Services SSO Identity Store API Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.account.assignment.init.create(
                ctx,
                instance_arn=value,
                target_id=value,
                target_type=value,
                permission_set_arn=value,
                principal_type=value,
                principal_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.account.assignment.init.create instance_arn=value, target_id=value, target_type=value, permission_set_arn=value, principal_type=value, principal_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="create_account_assignment",
        op_kwargs={
            "InstanceArn": instance_arn,
            "TargetId": target_id,
            "TargetType": target_type,
            "PermissionSetArn": permission_set_arn,
            "PrincipalType": principal_type,
            "PrincipalId": principal_id,
        },
    )


async def delete(
    hub,
    ctx,
    instance_arn: str,
    target_id: str,
    target_type: str,
    permission_set_arn: str,
    principal_type: str,
    principal_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a principal's access from a specified Amazon Web Services account using a specified permission set.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        target_id(str): TargetID is an Amazon Web Services account identifier, typically a 10-12 digit string (For example, 123456789012).
        target_type(str): The entity type for which the assignment will be deleted.
        permission_set_arn(str): The ARN of the permission set that will be used to remove access.
        principal_type(str): The entity type for which the assignment will be deleted.
        principal_id(str): An identifier for an object in Amazon Web Services SSO, such as a user or group. PrincipalIds are GUIDs (For example, f81d4fae-7dec-11d0-a765-00a0c91e6bf6). For more information about PrincipalIds in Amazon Web Services SSO, see the Amazon Web Services SSO Identity Store API Reference.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.account.assignment.init.delete(
                ctx,
                instance_arn=value,
                target_id=value,
                target_type=value,
                permission_set_arn=value,
                principal_type=value,
                principal_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.account.assignment.init.delete instance_arn=value, target_id=value, target_type=value, permission_set_arn=value, principal_type=value, principal_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="delete_account_assignment",
        op_kwargs={
            "InstanceArn": instance_arn,
            "TargetId": target_id,
            "TargetType": target_type,
            "PermissionSetArn": permission_set_arn,
            "PrincipalType": principal_type,
            "PrincipalId": principal_id,
        },
    )


async def list_all(
    hub,
    ctx,
    instance_arn: str,
    account_id: str,
    permission_set_arn: str,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the assignee of the specified Amazon Web Services account with the specified permission set.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
        account_id(str): The identifier of the Amazon Web Services account from which to list the assignments.
        permission_set_arn(str): The ARN of the permission set from which to list assignments.
        max_results(int, optional): The maximum number of results to display for the assignment. Defaults to None.
        next_token(str, optional): The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.account.assignment.init.list_all(
                ctx, instance_arn=value, account_id=value, permission_set_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.account.assignment.init.list_all instance_arn=value, account_id=value, permission_set_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="list_account_assignments",
        op_kwargs={
            "InstanceArn": instance_arn,
            "AccountId": account_id,
            "PermissionSetArn": permission_set_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the tags associated with the Amazon Resource Name (ARN) that you specify. The resource can be a user, server, or role.

    Args:
        arn(str): Requests the tags associated with a particular Amazon Resource Name (ARN). An ARN is an identifier for a specific Amazon Web Services resource, such as a server, user, or role.
        max_results(int, optional): Specifies the number of tags to return as a response to the ListTagsForResource request. Defaults to None.
        next_token(str, optional): When you request additional results from the ListTagsForResource operation, a NextToken parameter is returned in the input. You can then pass in a subsequent command to the NextToken parameter to continue listing additional tags. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.tags_for_resource.list(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.tags_for_resource.list arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="list_tags_for_resource",
        op_kwargs={"Arn": arn, "MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    profiling_group_name: str,
    end_time: str = None,
    frame_metrics: List = None,
    period: str = None,
    start_time: str = None,
    target_resolution: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the time series of values for a requested list of frame metrics from a time period.

    Args:
        end_time(str, optional):  The end time of the time period for the returned time series values. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC. . Defaults to None.
        frame_metrics(List, optional):  The details of the metrics that are used to request a time series of values. The metric includes the name of the frame, the aggregation type to calculate the metric value for the frame, and the thread states to use to get the count for the metric value of the frame. Defaults to None.
        period(str, optional):  The duration of the frame metrics used to return the time series values. Specify using the ISO 8601 format. The maximum period duration is one day (PT24H or P1D). . Defaults to None.
        profiling_group_name(str):  The name of the profiling group associated with the the frame metrics used to return the time series values. .
        start_time(str, optional):  The start time of the time period for the frame metrics used to return the time series values. This is specified using the ISO 8601 format. For example, 2020-06-01T13:15:02.001Z represents 1 millisecond past June 1, 2020 1:15:02 PM UTC. . Defaults to None.
        target_resolution(str, optional): The requested resolution of time steps for the returned time series of values. If the requested target resolution is not available due to data not being retained we provide a best effort result by falling back to the most granular available resolution after the target resolution. There are 3 valid values.     P1D — 1 day     PT1H — 1 hour     PT5M — 5 minutes   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.get_frame_metric_data.batch(
                ctx, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.get_frame_metric_data.batch profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="batch_get_frame_metric_data",
        op_kwargs={
            "endTime": end_time,
            "frameMetrics": frame_metrics,
            "period": period,
            "profilingGroupName": profiling_group_name,
            "startTime": start_time,
            "targetResolution": target_resolution,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    source_name: str = None,
    source_type: str = None,
    start_time: str = None,
    end_time: str = None,
    duration: int = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns events related to DAX clusters and parameter groups. You can obtain events specific to a particular DAX cluster or parameter group by providing the name as a parameter. By default, only the events occurring within the last 24 hours are returned; however, you can retrieve up to 14 days' worth of events if necessary.

    Args:
        source_name(str, optional): The identifier of the event source for which events will be returned. If not specified, then all sources are included in the response. Defaults to None.
        source_type(str, optional): The event source to retrieve events for. If no value is specified, all events are returned. Defaults to None.
        start_time(str, optional): The beginning of the time interval to retrieve events for, specified in ISO 8601 format. Defaults to None.
        end_time(str, optional): The end of the time interval for which to retrieve events, specified in ISO 8601 format. Defaults to None.
        duration(int, optional): The number of minutes' worth of events to retrieve. Defaults to None.
        max_results(int, optional): The maximum number of results to include in the response. If more results exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved. The value for MaxResults must be between 20 and 100. Defaults to None.
        next_token(str, optional): An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dax.event.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dax.event.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dax",
        operation="describe_events",
        op_kwargs={
            "SourceName": source_name,
            "SourceType": source_type,
            "StartTime": start_time,
            "EndTime": end_time,
            "Duration": duration,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub,
    ctx,
    local_gateway_virtual_interface_group_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified local gateway virtual interface groups.

    Args:
        local_gateway_virtual_interface_group_ids(List, optional): The IDs of the virtual interface groups. Defaults to None.
        filters(List, optional): One or more filters.    local-gateway-id - The ID of a local gateway.    local-gateway-virtual-interface-id - The ID of the virtual interface.    local-gateway-virtual-interface-group-id - The ID of the virtual interface group.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.local_gateway.virtual_interface.group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.local_gateway.virtual_interface.group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_local_gateway_virtual_interface_groups",
        op_kwargs={
            "LocalGatewayVirtualInterfaceGroupIds": local_gateway_virtual_interface_group_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, instance_arn: str, instance_access_control_attribute_configuration: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Enables the attributes-based access control (ABAC) feature for the specified Amazon Web Services SSO instance. You can also specify new attributes to add to your ABAC configuration during the enabling process. For more information about ABAC, see Attribute-Based Access Control in the Amazon Web Services SSO User Guide.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed.
        instance_access_control_attribute_configuration(Dict): Specifies the Amazon Web Services SSO identity store attributes to add to your ABAC configuration. When using an external identity provider as an identity source, you can pass attributes through the SAML assertion. Doing so provides an alternative to configuring attributes from the Amazon Web Services SSO identity store. If a SAML assertion passes any of these attributes, Amazon Web Services SSO will replace the attribute value with the value from the Amazon Web Services SSO identity store.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.instance.access_control_attribute_configuration.create(
                ctx, instance_arn=value, instance_access_control_attribute_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.instance.access_control_attribute_configuration.create instance_arn=value, instance_access_control_attribute_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="create_instance_access_control_attribute_configuration",
        op_kwargs={
            "InstanceArn": instance_arn,
            "InstanceAccessControlAttributeConfiguration": instance_access_control_attribute_configuration,
        },
    )


async def delete(hub, ctx, instance_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables the attributes-based access control (ABAC) feature for the specified Amazon Web Services SSO instance and deletes all of the attribute mappings that have been configured. Once deleted, any attributes that are received from an identity source and any custom attributes you have previously configured will not be passed. For more information about ABAC, see Attribute-Based Access Control in the Amazon Web Services SSO User Guide.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.instance.access_control_attribute_configuration.delete(
                ctx, instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.instance.access_control_attribute_configuration.delete instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="delete_instance_access_control_attribute_configuration",
        op_kwargs={"InstanceArn": instance_arn},
    )


async def describe(hub, ctx, instance_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the list of Amazon Web Services SSO identity store attributes that have been configured to work with attributes-based access control (ABAC) for the specified Amazon Web Services SSO instance. This will not return attributes configured and sent by an external identity provider. For more information about ABAC, see Attribute-Based Access Control in the Amazon Web Services SSO User Guide.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.instance.access_control_attribute_configuration.describe(
                ctx, instance_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.instance.access_control_attribute_configuration.describe instance_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="describe_instance_access_control_attribute_configuration",
        op_kwargs={"InstanceArn": instance_arn},
    )


async def update(
    hub, ctx, instance_arn: str, instance_access_control_attribute_configuration: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Amazon Web Services SSO identity store attributes that you can use with the Amazon Web Services SSO instance for attributes-based access control (ABAC). When using an external identity provider as an identity source, you can pass attributes through the SAML assertion as an alternative to configuring attributes from the Amazon Web Services SSO identity store. If a SAML assertion passes any of these attributes, Amazon Web Services SSO replaces the attribute value with the value from the Amazon Web Services SSO identity store. For more information about ABAC, see Attribute-Based Access Control in the Amazon Web Services SSO User Guide.

    Args:
        instance_arn(str): The ARN of the SSO instance under which the operation will be executed.
        instance_access_control_attribute_configuration(Dict): Updates the attributes for your ABAC configuration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sso_admin.instance.access_control_attribute_configuration.update(
                ctx, instance_arn=value, instance_access_control_attribute_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sso_admin.instance.access_control_attribute_configuration.update instance_arn=value, instance_access_control_attribute_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sso-admin",
        operation="update_instance_access_control_attribute_configuration",
        op_kwargs={
            "InstanceArn": instance_arn,
            "InstanceAccessControlAttributeConfiguration": instance_access_control_attribute_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    creator_request_id: str,
    security_group_ids: List,
    direction: str,
    ip_addresses: List,
    name: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Resolver endpoint. There are two types of Resolver endpoints, inbound and outbound:   An inbound Resolver endpoint forwards DNS queries to the DNS service for a VPC from your network.   An outbound Resolver endpoint forwards DNS queries from the DNS service for a VPC to your network.

    Args:
        creator_request_id(str): A unique string that identifies the request and that allows failed requests to be retried without the risk of running the operation twice. CreatorRequestId can be any unique string, for example, a date/time stamp. .
        name(str, optional): A friendly name that lets you easily find a configuration in the Resolver dashboard in the Route 53 console. Defaults to None.
        security_group_ids(List): The ID of one or more security groups that you want to use to control access to this VPC. The security group that you specify must include one or more inbound rules (for inbound Resolver endpoints) or outbound rules (for outbound Resolver endpoints). Inbound and outbound rules must allow TCP and UDP access. For inbound access, open port 53. For outbound access, open the port that you're using for DNS queries on your network.
        direction(str): Specify the applicable value:    INBOUND: Resolver forwards DNS queries to the DNS service for a VPC from your network    OUTBOUND: Resolver forwards DNS queries from the DNS service for a VPC to your network  .
        ip_addresses(List): The subnets and IP addresses in your VPC that DNS queries originate from (for outbound endpoints) or that you forward DNS queries to (for inbound endpoints). The subnet ID uniquely identifies a VPC. .
        tags(List, optional): A list of the tag keys and values that you want to associate with the endpoint. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.endpoint.init.create(
                ctx,
                creator_request_id=value,
                security_group_ids=value,
                direction=value,
                ip_addresses=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.endpoint.init.create creator_request_id=value, security_group_ids=value, direction=value, ip_addresses=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="create_resolver_endpoint",
        op_kwargs={
            "CreatorRequestId": creator_request_id,
            "Name": name,
            "SecurityGroupIds": security_group_ids,
            "Direction": direction,
            "IpAddresses": ip_addresses,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, resolver_endpoint_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Resolver endpoint. The effect of deleting a Resolver endpoint depends on whether it's an inbound or an outbound Resolver endpoint:    Inbound: DNS queries from your network are no longer routed to the DNS service for the specified VPC.    Outbound: DNS queries from a VPC are no longer routed to your network.

    Args:
        resolver_endpoint_id(str): The ID of the Resolver endpoint that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.endpoint.init.delete(
                ctx, resolver_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.endpoint.init.delete resolver_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="delete_resolver_endpoint",
        op_kwargs={"ResolverEndpointId": resolver_endpoint_id},
    )


async def get(hub, ctx, resolver_endpoint_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified Resolver endpoint, such as whether it's an inbound or an outbound Resolver endpoint, and the current status of the endpoint.

    Args:
        resolver_endpoint_id(str): The ID of the Resolver endpoint that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.endpoint.init.get(
                ctx, resolver_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.endpoint.init.get resolver_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="get_resolver_endpoint",
        op_kwargs={"ResolverEndpointId": resolver_endpoint_id},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the Resolver endpoints that were created using the current AWS account.

    Args:
        max_results(int, optional): The maximum number of Resolver endpoints that you want to return in the response to a ListResolverEndpoints request. If you don't specify a value for MaxResults, Resolver returns up to 100 Resolver endpoints. . Defaults to None.
        next_token(str, optional): For the first ListResolverEndpoints request, omit this value. If you have more than MaxResults Resolver endpoints, you can submit another ListResolverEndpoints request to get the next group of Resolver endpoints. In the next request, specify the value of NextToken from the previous response. . Defaults to None.
        filters(List, optional): An optional specification to return a subset of Resolver endpoints, such as all inbound Resolver endpoints.  If you submit a second or subsequent ListResolverEndpoints request and specify the NextToken parameter, you must use the same values for Filters, if any, as in the previous request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.endpoint.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.endpoint.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_resolver_endpoints",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )


async def update(hub, ctx, resolver_endpoint_id: str, name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the name of an inbound or an outbound Resolver endpoint.

    Args:
        resolver_endpoint_id(str): The ID of the Resolver endpoint that you want to update.
        name(str, optional): The name of the Resolver endpoint that you want to update. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.resolver.endpoint.init.update(
                ctx, resolver_endpoint_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.resolver.endpoint.init.update resolver_endpoint_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="update_resolver_endpoint",
        op_kwargs={"ResolverEndpointId": resolver_endpoint_id, "Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, organization_id: str, entity_id: str, alias: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds an alias to the set of a given member (user or group) of Amazon WorkMail.

    Args:
        organization_id(str): The organization under which the member (user or group) exists.
        entity_id(str): The member (user or group) to which this alias is added.
        alias(str): The alias to add to the member set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.alias.create(
                ctx, organization_id=value, entity_id=value, alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.alias.create organization_id=value, entity_id=value, alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="create_alias",
        op_kwargs={
            "OrganizationId": organization_id,
            "EntityId": entity_id,
            "Alias": alias,
        },
    )


async def delete(hub, ctx, organization_id: str, entity_id: str, alias: str) -> Dict:
    r"""
    **Autogenerated function**

    Remove one or more specified aliases from a set of aliases for a given user.

    Args:
        organization_id(str): The identifier for the organization under which the user exists.
        entity_id(str): The identifier for the member (user or group) from which to have the aliases removed.
        alias(str): The aliases to be removed from the user's set of aliases. Duplicate entries in the list are collapsed into single entries (the list is transformed into a set).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.alias.delete(
                ctx, organization_id=value, entity_id=value, alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.alias.delete organization_id=value, entity_id=value, alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="delete_alias",
        op_kwargs={
            "OrganizationId": organization_id,
            "EntityId": entity_id,
            "Alias": alias,
        },
    )


async def list_all(
    hub,
    ctx,
    organization_id: str,
    entity_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a paginated call to list the aliases associated with a given entity.

    Args:
        organization_id(str): The identifier for the organization under which the entity exists.
        entity_id(str): The identifier for the entity for which to list the aliases.
        next_token(str, optional): The token to use to retrieve the next page of results. The first call does not contain any tokens. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.alias.list_all(
                ctx, organization_id=value, entity_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.alias.list_all organization_id=value, entity_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="list_aliases",
        op_kwargs={
            "OrganizationId": organization_id,
            "EntityId": entity_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    input_: Dict,
    output: Dict,
    name: str,
    settings: Dict,
    role_arn: str,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Rekognition stream processor that you can use to detect and recognize faces in a streaming video. Amazon Rekognition Video is a consumer of live video from Amazon Kinesis Video Streams. Amazon Rekognition Video sends analysis results to Amazon Kinesis Data Streams. You provide as input a Kinesis video stream (Input) and a Kinesis data stream (Output) stream. You also specify the face recognition criteria in Settings. For example, the collection containing faces that you want to recognize. Use Name to assign an identifier for the stream processor. You use Name to manage the stream processor. For example, you can start processing the source video by calling StartStreamProcessor with the Name field.  After you have finished analyzing a streaming video, use StopStreamProcessor to stop processing. You can delete the stream processor by calling DeleteStreamProcessor. This operation requires permissions to perform the rekognition:CreateStreamProcessor action. If you want to tag your stream processor, you also require permission to perform the rekognition:TagResource operation.

    Args:
        input_(Dict): Kinesis video stream stream that provides the source streaming video. If you are using the AWS CLI, the parameter name is StreamProcessorInput.
        output(Dict): Kinesis data stream stream to which Amazon Rekognition Video puts the analysis results. If you are using the AWS CLI, the parameter name is StreamProcessorOutput.
        name(str): An identifier you assign to the stream processor. You can use Name to manage the stream processor. For example, you can get the current status of the stream processor by calling DescribeStreamProcessor. Name is idempotent. .
        settings(Dict): Face recognition input parameters to be used by the stream processor. Includes the collection to use for face recognition and the face attributes to detect.
        role_arn(str): ARN of the IAM role that allows access to the stream processor.
        tags(Dict, optional):  A set of tags (key-value pairs) that you want to attach to the stream processor. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.stream_processor.create(
                ctx, input_=value, output=value, name=value, settings=value, role_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.stream_processor.create input_=value, output=value, name=value, settings=value, role_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="create_stream_processor",
        op_kwargs={
            "Input": input_,
            "Output": output,
            "Name": name,
            "Settings": settings,
            "RoleArn": role_arn,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the stream processor identified by Name. You assign the value for Name when you create the stream processor with CreateStreamProcessor. You might not be able to use the same name for a stream processor for a few seconds after calling DeleteStreamProcessor.

    Args:
        name(str): The name of the stream processor you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.stream_processor.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.stream_processor.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="delete_stream_processor",
        op_kwargs={"Name": name},
    )


async def describe(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides information about a stream processor created by CreateStreamProcessor. You can get information about the input and output streams, the input parameters for the face recognition being performed, and the current status of the stream processor.

    Args:
        name(str): Name of the stream processor for which you want information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.stream_processor.describe(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.stream_processor.describe name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="describe_stream_processor",
        op_kwargs={"Name": name},
    )


async def list_all(hub, ctx, next_token: str = None, max_results: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of stream processors that you have created with CreateStreamProcessor.

    Args:
        next_token(str, optional): If the previous response was incomplete (because there are more stream processors to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of stream processors. . Defaults to None.
        max_results(int, optional): Maximum number of stream processors you want Amazon Rekognition Video to return in the response. The default is 1000. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.stream_processor.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.stream_processor.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="list_stream_processors",
        op_kwargs={"NextToken": next_token, "MaxResults": max_results},
    )


async def start(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts processing a stream processor. You create a stream processor by calling CreateStreamProcessor. To tell StartStreamProcessor which stream processor to start, use the value of the Name field specified in the call to CreateStreamProcessor.

    Args:
        name(str): The name of the stream processor to start processing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.stream_processor.start(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.stream_processor.start name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_stream_processor",
        op_kwargs={"Name": name},
    )


async def stop(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a running stream processor that was created by CreateStreamProcessor.

    Args:
        name(str): The name of a stream processor created by CreateStreamProcessor.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.stream_processor.stop(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.stream_processor.stop name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="stop_stream_processor",
        op_kwargs={"Name": name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    vpc_id: str,
    vpc_region: str,
    max_items: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the private hosted zones that a specified VPC is associated with, regardless of which account or Amazon Web Services service owns the hosted zones. The HostedZoneOwner structure in the response contains one of the following values:   An OwningAccount element, which contains the account number of either the current account or another account. Some services, such as Cloud Map, create hosted zones using the current account.    An OwningService element, which identifies the Amazon Web Services service that created and owns the hosted zone. For example, if a hosted zone was created by Amazon Elastic File System (Amazon EFS), the value of Owner is efs.amazonaws.com.

    Args:
        vpc_id(str): The ID of the Amazon VPC that you want to list hosted zones for.
        vpc_region(str): For the Amazon VPC that you specified for VPCId, the Amazon Web Services Region that you created the VPC in. .
        max_items(str, optional): (Optional) The maximum number of hosted zones that you want Amazon Route 53 to return. If the specified VPC is associated with more than MaxItems hosted zones, the response includes a NextToken element. NextToken contains an encrypted token that identifies the first hosted zone that Route 53 will return if you submit another request. Defaults to None.
        next_token(str, optional): If the previous response included a NextToken element, the specified VPC is associated with more hosted zones. To get more hosted zones, submit another ListHostedZonesByVPC request.  For the value of NextToken, specify the value of NextToken from the previous response. If the previous response didn't include a NextToken element, there are no more hosted zones to get. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.hosted_zone.by.vpc.list(
                ctx, vpc_id=value, vpc_region=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.hosted_zone.by.vpc.list vpc_id=value, vpc_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_hosted_zones_by_vpc",
        op_kwargs={
            "VPCId": vpc_id,
            "VPCRegion": vpc_region,
            "MaxItems": max_items,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, workload_id: str, milestone_name: str, client_request_token: str
) -> Dict:
    r"""
    **Autogenerated function**

    Create a milestone for an existing workload.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        milestone_name(str): The name of the milestone in a workload. Milestone names must be unique within a workload.
        client_request_token(str): A unique case-sensitive string used to ensure that this request is idempotent (executes only once). You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after it has completed successfully, the result of the original request is returned.   This token is listed as required, however, if you do not specify it, the AWS SDKs automatically generate one for you. If you are not using the AWS SDK or the AWS CLI, you must provide this token or the request will fail. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.milestone.create(
                ctx, workload_id=value, milestone_name=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.milestone.create workload_id=value, milestone_name=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="create_milestone",
        op_kwargs={
            "WorkloadId": workload_id,
            "MilestoneName": milestone_name,
            "ClientRequestToken": client_request_token,
        },
    )


async def get(hub, ctx, workload_id: str, milestone_number: int) -> Dict:
    r"""
    **Autogenerated function**

    Get a milestone for an existing workload.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        milestone_number(int): The milestone number. A workload can have a maximum of 100 milestones.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.milestone.get(
                ctx, workload_id=value, milestone_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.milestone.get workload_id=value, milestone_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="get_milestone",
        op_kwargs={"WorkloadId": workload_id, "MilestoneNumber": milestone_number},
    )


async def list_all(
    hub, ctx, workload_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    List all milestones for an existing workload.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        next_token(str, optional): The token to use to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.milestone.list_all(ctx, workload_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.milestone.list_all workload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="list_milestones",
        op_kwargs={
            "WorkloadId": workload_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub, ctx, vpc_id: str, instance_tenancy: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the instance tenancy attribute of the specified VPC. You can change the instance tenancy attribute of a VPC to default only. You cannot change the instance tenancy attribute to dedicated. After you modify the tenancy of the VPC, any new instances that you launch into the VPC have a tenancy of default, unless you specify otherwise during launch. The tenancy of any existing instances in the VPC is not affected. For more information, see Dedicated Instances in the Amazon Elastic Compute Cloud User Guide.

    Args:
        vpc_id(str): The ID of the VPC.
        instance_tenancy(str): The instance tenancy attribute for the VPC. .
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpc.tenancy.modify(
                ctx, vpc_id=value, instance_tenancy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpc.tenancy.modify vpc_id=value, instance_tenancy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_vpc_tenancy",
        op_kwargs={
            "VpcId": vpc_id,
            "InstanceTenancy": instance_tenancy,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, position: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the RestApis resources for your collection.

    Args:
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.rest_apis.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.rest_apis.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_rest_apis",
        op_kwargs={"position": position, "limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes auto scaling settings across replicas of the global table at once.  This operation only applies to Version 2019.11.21 of global tables.

    Args:
        table_name(str): The name of the table.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.replica_auto_scaling.describe(
                ctx, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.replica_auto_scaling.describe table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="describe_table_replica_auto_scaling",
        op_kwargs={"TableName": table_name},
    )


async def update(
    hub,
    ctx,
    table_name: str,
    global_secondary_index_updates: List = None,
    provisioned_write_capacity_auto_scaling_update: Dict = None,
    replica_updates: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates auto scaling settings on your global tables at once.  This operation only applies to Version 2019.11.21 of global tables.

    Args:
        global_secondary_index_updates(List, optional): Represents the auto scaling settings of the global secondary indexes of the replica to be updated. Defaults to None.
        table_name(str): The name of the global table to be updated.
        provisioned_write_capacity_auto_scaling_update(Dict, optional): Represents the auto scaling settings to be modified for a global table or global secondary index. Defaults to None.
        replica_updates(List, optional): Represents the auto scaling settings of replicas of the table that will be modified. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.table.replica_auto_scaling.update(
                ctx, table_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.table.replica_auto_scaling.update table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="update_table_replica_auto_scaling",
        op_kwargs={
            "GlobalSecondaryIndexUpdates": global_secondary_index_updates,
            "TableName": table_name,
            "ProvisionedWriteCapacityAutoScalingUpdate": provisioned_write_capacity_auto_scaling_update,
            "ReplicaUpdates": replica_updates,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, instance_id: str, snapshot_id: str, baseline_override: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the current snapshot for the patch baseline the instance uses. This API is primarily used by the AWS-RunPatchBaseline Systems Manager document (SSM document).  If you run the command locally, such as with the Command Line Interface (CLI), the system attempts to use your local AWS credentials and the operation fails. To avoid this, you can run the command in the Amazon Web Services Systems Manager console. Use Run Command, a capability of Amazon Web Services Systems Manager, with an SSM document that enables you to target an instance with a script or command. For example, run the command using the AWS-RunShellScript document or the AWS-RunPowerShellScript document.

    Args:
        instance_id(str): The ID of the instance for which the appropriate patch snapshot should be retrieved.
        snapshot_id(str): The snapshot ID provided by the user when running AWS-RunPatchBaseline.
        baseline_override(Dict, optional): Defines the basic information about a patch baseline override. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.deployable_patch_snapshot_for_instance.get(
                ctx, instance_id=value, snapshot_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.deployable_patch_snapshot_for_instance.get instance_id=value, snapshot_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_deployable_patch_snapshot_for_instance",
        op_kwargs={
            "InstanceId": instance_id,
            "SnapshotId": snapshot_id,
            "BaselineOverride": baseline_override,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub, ctx, deletion_id: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes a specific delete inventory operation.

    Args:
        deletion_id(str, optional): Specify the delete inventory ID for which you want information. This ID was returned by the DeleteInventory operation. Defaults to None.
        next_token(str, optional): A token to start the list. Use this token to get the next set of results. . Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.inventory.deletion.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.inventory.deletion.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_inventory_deletions",
        op_kwargs={
            "DeletionId": deletion_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    project_arn: str,
    device_arn: str,
    instance_arn: str = None,
    ssh_public_key: str = None,
    remote_debug_enabled: bool = None,
    remote_record_enabled: bool = None,
    remote_record_app_arn: str = None,
    name: str = None,
    client_id: str = None,
    configuration: Dict = None,
    interaction_mode: str = None,
    skip_app_resign: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Specifies and starts a remote access session.

    Args:
        project_arn(str): The Amazon Resource Name (ARN) of the project for which you want to create a remote access session.
        device_arn(str): The ARN of the device for which you want to create a remote access session.
        instance_arn(str, optional): The Amazon Resource Name (ARN) of the device instance for which you want to create a remote access session. Defaults to None.
        ssh_public_key(str, optional): Ignored. The public key of the ssh key pair you want to use for connecting to remote devices in your remote debugging session. This key is required only if remoteDebugEnabled is set to true. Remote debugging is no longer supported. Defaults to None.
        remote_debug_enabled(bool, optional): Set to true if you want to access devices remotely for debugging in your remote access session. Remote debugging is no longer supported. Defaults to None.
        remote_record_enabled(bool, optional): Set to true to enable remote recording for the remote access session. Defaults to None.
        remote_record_app_arn(str, optional): The Amazon Resource Name (ARN) for the app to be recorded in the remote access session. Defaults to None.
        name(str, optional): The name of the remote access session to create. Defaults to None.
        client_id(str, optional): Unique identifier for the client. If you want access to multiple devices on the same client, you should pass the same clientId value in each call to CreateRemoteAccessSession. This identifier is required only if remoteDebugEnabled is set to true. Remote debugging is no longer supported. Defaults to None.
        configuration(Dict, optional): The configuration information for the remote access session request. Defaults to None.
        interaction_mode(str, optional): The interaction mode of the remote access session. Valid values are:   INTERACTIVE: You can interact with the iOS device by viewing, touching, and rotating the screen. You cannot run XCUITest framework-based tests in this mode.   NO_VIDEO: You are connected to the device, but cannot interact with it or view the screen. This mode has the fastest test execution speed. You can run XCUITest framework-based tests in this mode.   VIDEO_ONLY: You can view the screen, but cannot touch or rotate it. You can run XCUITest framework-based tests and watch the screen in this mode.  . Defaults to None.
        skip_app_resign(bool, optional): When set to true, for private devices, Device Farm does not sign your app again. For public devices, Device Farm always signs your apps again. For more information on how Device Farm modifies your uploads during tests, see Do you modify my app? . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.remote_access_session.create(
                ctx, project_arn=value, device_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.remote_access_session.create project_arn=value, device_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="create_remote_access_session",
        op_kwargs={
            "projectArn": project_arn,
            "deviceArn": device_arn,
            "instanceArn": instance_arn,
            "sshPublicKey": ssh_public_key,
            "remoteDebugEnabled": remote_debug_enabled,
            "remoteRecordEnabled": remote_record_enabled,
            "remoteRecordAppArn": remote_record_app_arn,
            "name": name,
            "clientId": client_id,
            "configuration": configuration,
            "interactionMode": interaction_mode,
            "skipAppResign": skip_app_resign,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a completed remote access session and its results.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the session for which you want to delete remote access.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.remote_access_session.delete(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.remote_access_session.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="delete_remote_access_session",
        op_kwargs={"arn": arn},
    )


async def get(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns a link to a currently running remote access session.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the remote access session about which you want to get session information.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.remote_access_session.get(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.remote_access_session.get arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="get_remote_access_session",
        op_kwargs={"arn": arn},
    )


async def list_all(hub, ctx, arn: str, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all currently running remote access sessions.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the project about which you are requesting information.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.remote_access_session.list_all(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.remote_access_session.list_all arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="list_remote_access_sessions",
        op_kwargs={"arn": arn, "nextToken": next_token},
    )


async def stop(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Ends a specified remote access session.

    Args:
        arn(str): The Amazon Resource Name (ARN) of the remote access session to stop.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devicefarm.remote_access_session.stop(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devicefarm.remote_access_session.stop arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devicefarm",
        operation="stop_remote_access_session",
        op_kwargs={"arn": arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns details about an insight that you specify using its ID.

    Args:
        id_(str):  The ID of the insight. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.insight.describe(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.insight.describe id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="describe_insight",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub, ctx, status_filter: Dict, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of insights in your AWS account. You can specify which insights are returned by their start time and status (ONGOING, CLOSED, or ANY).

    Args:
        status_filter(Dict):  A filter used to filter the returned insights by their status. You can specify one status filter. .
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.insight.list_all(ctx, status_filter=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.insight.list_all status_filter=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="list_insights",
        op_kwargs={
            "StatusFilter": status_filter,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def search(
    hub,
    ctx,
    start_time_range: Dict,
    type_: str,
    filters: Dict = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of insights in your AWS account. You can specify which insights are returned by their start time, one or more statuses (ONGOING, CLOSED, and CLOSED), one or more severities (LOW, MEDIUM, and HIGH), and type (REACTIVE or PROACTIVE).   Use the Filters parameter to specify status and severity search parameters. Use the Type parameter to specify REACTIVE or PROACTIVE in your search.

    Args:
        start_time_range(Dict):  The start of the time range passed in. Returned insights occurred after this time. .
        filters(Dict, optional):  A SearchInsightsFilters object that is used to set the severity and status filters on your insight search. . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.
        type_(str):  The type of insights you are searching for (REACTIVE or PROACTIVE). .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.insight.search(
                ctx, start_time_range=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.insight.search start_time_range=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="search_insights",
        op_kwargs={
            "StartTimeRange": start_time_range,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Type": type_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def associate(hub, ctx, log_group_name: str, kms_key_id: str) -> None:
    r"""
    **Autogenerated function**

    Associates the specified AWS Key Management Service (AWS KMS) customer master key (CMK) with the specified log group. Associating an AWS KMS CMK with a log group overrides any existing associations between the log group and a CMK. After a CMK is associated with a log group, all newly ingested data for the log group is encrypted using the CMK. This association is stored as long as the data encrypted with the CMK is still within Amazon CloudWatch Logs. This enables Amazon CloudWatch Logs to decrypt this data whenever it is requested.  CloudWatch Logs supports only symmetric CMKs. Do not use an associate an asymmetric CMK with your log group. For more information, see Using Symmetric and Asymmetric Keys.  It can take up to 5 minutes for this operation to take effect. If you attempt to associate a CMK with a log group but the CMK does not exist or the CMK is disabled, you receive an InvalidParameterException error.

    Args:
        log_group_name(str): The name of the log group.
        kms_key_id(str): The Amazon Resource Name (ARN) of the CMK to use when encrypting log data. This must be a symmetric CMK. For more information, see Amazon Resource Names - AWS Key Management Service (AWS KMS) and Using Symmetric and Asymmetric Keys.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.kms_key.associate(
                ctx, log_group_name=value, kms_key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.kms_key.associate log_group_name=value, kms_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="associate_kms_key",
        op_kwargs={"logGroupName": log_group_name, "kmsKeyId": kms_key_id},
    )


async def disassociate(hub, ctx, log_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Disassociates the associated AWS Key Management Service (AWS KMS) customer master key (CMK) from the specified log group. After the AWS KMS CMK is disassociated from the log group, AWS CloudWatch Logs stops encrypting newly ingested data for the log group. All previously ingested data remains encrypted, and AWS CloudWatch Logs requires permissions for the CMK whenever the encrypted data is requested. Note that it can take up to 5 minutes for this operation to take effect.

    Args:
        log_group_name(str): The name of the log group.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.kms_key.disassociate(ctx, log_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.kms_key.disassociate log_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="disassociate_kms_key",
        op_kwargs={"logGroupName": log_group_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, max_results: int = None, filters: List = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all patch groups that have been registered with patch baselines.

    Args:
        max_results(int, optional): The maximum number of patch groups to return (per page). Defaults to None.
        filters(List, optional): Each element in the array is a structure containing a key-value pair. Supported keys for DescribePatchGroups include the following:     NAME_PREFIX   Sample values: AWS- | My-.     OPERATING_SYSTEM   Sample values: AMAZON_LINUX | SUSE | WINDOWS   . Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.patch.group.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.patch.group.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_patch_groups",
        op_kwargs={
            "MaxResults": max_results,
            "Filters": filters,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    flow_log_id: str,
    config_delivery_s3_destination_arn: str,
    integrate_services: Dict,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates a CloudFormation template that streamlines and automates the integration of VPC flow logs with Amazon Athena. This make it easier for you to query and gain insights from VPC flow logs data. Based on the information that you provide, we configure resources in the template to do the following:   Create a table in Athena that maps fields to a custom log format   Create a Lambda function that updates the table with new partitions on a daily, weekly, or monthly basis   Create a table partitioned between two timestamps in the past   Create a set of named queries in Athena that you can use to get started quickly

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        flow_log_id(str): The ID of the flow log.
        config_delivery_s3_destination_arn(str): To store the CloudFormation template in Amazon S3, specify the location in Amazon S3.
        integrate_services(Dict): Information about the service integration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.flow_logs_integration_template.get(
                ctx,
                flow_log_id=value,
                config_delivery_s3_destination_arn=value,
                integrate_services=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.flow_logs_integration_template.get flow_log_id=value, config_delivery_s3_destination_arn=value, integrate_services=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_flow_logs_integration_template",
        op_kwargs={
            "DryRun": dry_run,
            "FlowLogId": flow_log_id,
            "ConfigDeliveryS3DestinationArn": config_delivery_s3_destination_arn,
            "IntegrateServices": integrate_services,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, application_name: str, application_maintenance_configuration_update: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the maintenance configuration of the Kinesis Data Analytics application.  You can invoke this operation on an application that is in one of the two following states: READY or RUNNING. If you invoke it when the application is in a state other than these two states, it throws a ResourceInUseException. The service makes use of the updated configuration the next time it schedules maintenance for the application. If you invoke this operation after the service schedules maintenance, the service will apply the configuration update the next time it schedules maintenance for the application. This means that you might not see the maintenance configuration update applied to the maintenance process that follows a successful invocation of this operation, but to the following maintenance process instead. To see the current maintenance configuration of your application, invoke the DescribeApplication operation. For information about application maintenance, see Kinesis Data Analytics for Apache Flink Maintenance.  This operation is supported only for Amazon Kinesis Data Analytics for Apache Flink.

    Args:
        application_name(str): The name of the application for which you want to update the maintenance configuration.
        application_maintenance_configuration_update(Dict): Describes the application maintenance configuration update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.maintenance_configuration.update(
                ctx, application_name=value, application_maintenance_configuration_update=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.maintenance_configuration.update application_name=value, application_maintenance_configuration_update=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="update_application_maintenance_configuration",
        op_kwargs={
            "ApplicationName": application_name,
            "ApplicationMaintenanceConfigurationUpdate": application_maintenance_configuration_update,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, id_: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets revisions made to the specified system template. Only the previous 100 revisions are stored. If the system has been deprecated, this action will return the revisions that occurred before its deprecation. This action won't work with systems that have been deleted.

    Args:
        id_(str): The ID of the system template. The ID should be in the following format.  urn:tdm:REGION/ACCOUNT ID/default:system:SYSTEMNAME .
        next_token(str, optional): The string that specifies the next page of results. Use this when you're paginating results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotthingsgraph.system.template.revision.get_all(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotthingsgraph.system.template.revision.get_all id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotthingsgraph",
        operation="get_system_template_revisions",
        op_kwargs={"id": id_, "nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, log_record_pointer: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all of the fields and values of a single log event. All fields are retrieved, even if the original query that produced the logRecordPointer retrieved only a subset of fields. Fields are returned as field name/field value pairs. The full unparsed log event is returned within @message.

    Args:
        log_record_pointer(str): The pointer corresponding to the log event record you want to retrieve. You get this from the response of a GetQueryResults operation. In that response, the value of the @ptr field for a log event is the value to use as logRecordPointer to retrieve that complete log event record.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.record.get(ctx, log_record_pointer=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.record.get log_record_pointer=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="get_log_record",
        op_kwargs={"logRecordPointer": log_record_pointer},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the details of a gateway.

    Args:
        gateway_arn(str): The ARN of the gateway to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.gateway.init.get(ctx, gateway_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.gateway.init.get gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="get_gateway",
        op_kwargs={"GatewayArn": gateway_arn},
    )


async def list_all(
    hub,
    ctx,
    gateway_group_arn: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of gateway summaries. Use GetGateway to retrieve details of a specific gateway. An optional gateway group ARN can be provided to only retrieve gateway summaries of gateways that are associated with that gateway group ARN.

    Args:
        gateway_group_arn(str, optional): The gateway group ARN for which to list gateways. Defaults to None.
        next_token(str, optional): The token used to paginate though multiple pages of gateway summaries. Defaults to None.
        max_results(int, optional): The maximum number of gateway summaries to return. The default is 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.gateway.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.gateway.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="list_gateways",
        op_kwargs={
            "GatewayGroupArn": gateway_group_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    gateway_arn: str,
    name: str = None,
    description: str = None,
    software_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the details of a gateway. If any optional field is not provided, the existing corresponding value is left unmodified.

    Args:
        gateway_arn(str): The ARN of the gateway to update.
        name(str, optional): The updated name of the gateway. Defaults to None.
        description(str, optional): The updated description of the gateway. Defaults to None.
        software_version(str, optional): The updated software version of the gateway. The gateway automatically updates its software version during normal operation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.gateway.init.update(ctx, gateway_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.gateway.init.update gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="update_gateway",
        op_kwargs={
            "GatewayArn": gateway_arn,
            "Name": name,
            "Description": description,
            "SoftwareVersion": software_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    user_name: str,
    password: str,
    client_token: str,
    gateway_arn: str,
    location_arn: str,
    tags: List = None,
    audit_destination_arn: str = None,
    cache_attributes: Dict = None,
    endpoint_network_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associate an Amazon FSx file system with the FSx File Gateway. After the association process is complete, the file shares on the Amazon FSx file system are available for access through the gateway. This operation only supports the FSx File Gateway type.

    Args:
        user_name(str): The user name of the user credential that has permission to access the root share D$ of the Amazon FSx file system. The user account must belong to the Amazon FSx delegated admin user group.
        password(str): The password of the user credential.
        client_token(str): A unique string value that you supply that is used by the FSx File Gateway to ensure idempotent file system association creation.
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        location_arn(str): The Amazon Resource Name (ARN) of the Amazon FSx file system to associate with the FSx File Gateway.
        tags(List, optional): A list of up to 50 tags that can be assigned to the file system association. Each tag is a key-value pair. Defaults to None.
        audit_destination_arn(str, optional): The Amazon Resource Name (ARN) of the storage used for the audit logs. Defaults to None.
        cache_attributes(Dict, optional): The refresh cache information for the file share or FSx file systems. Defaults to None.
        endpoint_network_configuration(Dict, optional): Specifies the network configuration information for the gateway associated with the Amazon FSx file system.  If multiple file systems are associated with this gateway, this parameter's IpAddresses field is required. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.file.system.init.associate(
                ctx,
                user_name=value,
                password=value,
                client_token=value,
                gateway_arn=value,
                location_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.file.system.init.associate user_name=value, password=value, client_token=value, gateway_arn=value, location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="associate_file_system",
        op_kwargs={
            "UserName": user_name,
            "Password": password,
            "ClientToken": client_token,
            "GatewayARN": gateway_arn,
            "LocationARN": location_arn,
            "Tags": tags,
            "AuditDestinationARN": audit_destination_arn,
            "CacheAttributes": cache_attributes,
            "EndpointNetworkConfiguration": endpoint_network_configuration,
        },
    )


async def disassociate(
    hub, ctx, file_system_association_arn: str, force_delete: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates an Amazon FSx file system from the specified gateway. After the disassociation process finishes, the gateway can no longer access the Amazon FSx file system. This operation is only supported in the FSx File Gateway type.

    Args:
        file_system_association_arn(str): The Amazon Resource Name (ARN) of the file system association to be deleted.
        force_delete(bool, optional): If this value is set to true, the operation disassociates an Amazon FSx file system immediately. It ends all data uploads to the file system, and the file system association enters the FORCE_DELETING status. If this value is set to false, the Amazon FSx file system does not disassociate until all data is uploaded. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.file.system.init.disassociate(
                ctx, file_system_association_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.file.system.init.disassociate file_system_association_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="disassociate_file_system",
        op_kwargs={
            "FileSystemAssociationARN": file_system_association_arn,
            "ForceDelete": force_delete,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    instance_id: str,
    lex_version: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and is subject to change. For the specified version of Amazon Lex, returns a paginated list of all the Amazon Lex bots currently associated with the instance.

    Args:
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.
        next_token(str, optional): The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per page. Defaults to None.
        lex_version(str): The version of Amazon Lex or Amazon Lex V2.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.bots.list(ctx, instance_id=value, lex_version=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.bots.list instance_id=value, lex_version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="list_bots",
        op_kwargs={
            "InstanceId": instance_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "LexVersion": lex_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, file_system_id: str, aliases: List, client_request_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Use this action to associate one or more Domain Name Server (DNS) aliases with an existing Amazon FSx for Windows File Server file system. A file systen can have a maximum of 50 DNS aliases associated with it at any one time. If you try to associate a DNS alias that is already associated with the file system, FSx takes no action on that alias in the request. For more information, see Working with DNS Aliases and Walkthrough 5: Using DNS aliases to access your file system, including additional steps you must take to be able to access your file system using a DNS alias. The system response shows the DNS aliases that Amazon FSx is attempting to associate with the file system. Use the API operation to monitor the status of the aliases Amazon FSx is associating with the file system.

    Args:
        client_request_token(str, optional): (Optional) An idempotency token for resource creation, in a string of up to 64 ASCII characters. This token is automatically filled on your behalf when you use the AWS Command Line Interface (AWS CLI) or an AWS SDK. Defaults to None.
        file_system_id(str): Specifies the file system with which you want to associate one or more DNS aliases.
        aliases(List): An array of one or more DNS alias names to associate with the file system. The alias name has to comply with the following formatting requirements:   Formatted as a fully-qualified domain name (FQDN),  hostname.domain , for example, accounting.corp.example.com.   Can contain alphanumeric characters and the hyphen (-).   Cannot start or end with a hyphen.   Can start with a numeric.   For DNS alias names, Amazon FSx stores alphabetic characters as lowercase letters (a-z), regardless of how you specify them: as uppercase letters, lowercase letters, or the corresponding letters in escape codes.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.file_system.aliase.associate(
                ctx, file_system_id=value, aliases=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.file_system.aliase.associate file_system_id=value, aliases=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="associate_file_system_aliases",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "FileSystemId": file_system_id,
            "Aliases": aliases,
        },
    )


async def describe_all(
    hub,
    ctx,
    file_system_id: str,
    client_request_token: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the DNS aliases that are associated with the specified Amazon FSx for Windows File Server file system. A history of all DNS aliases that have been associated with and disassociated from the file system is available in the list of AdministrativeAction provided in the DescribeFileSystems operation response.

    Args:
        client_request_token(str, optional): (Optional) An idempotency token for resource creation, in a string of up to 64 ASCII characters. This token is automatically filled on your behalf when you use the AWS Command Line Interface (AWS CLI) or an AWS SDK. Defaults to None.
        file_system_id(str): The ID of the file system to return the associated DNS aliases for (String).
        max_results(int, optional): Maximum number of DNS aliases to return in the response (integer). This parameter value must be greater than 0. The number of items that Amazon FSx returns is the minimum of the MaxResults parameter specified in the request and the service's internal maximum number of items per page. Defaults to None.
        next_token(str, optional): Opaque pagination token returned from a previous DescribeFileSystemAliases operation (String). If a token is included in the request, the action continues the list from where the previous returning call left off. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.file_system.aliase.describe_all(ctx, file_system_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.file_system.aliase.describe_all file_system_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="describe_file_system_aliases",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "FileSystemId": file_system_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def disassociate(
    hub, ctx, file_system_id: str, aliases: List, client_request_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Use this action to disassociate, or remove, one or more Domain Name Service (DNS) aliases from an Amazon FSx for Windows File Server file system. If you attempt to disassociate a DNS alias that is not associated with the file system, Amazon FSx responds with a 400 Bad Request. For more information, see Working with DNS Aliases. The system generated response showing the DNS aliases that Amazon FSx is attempting to disassociate from the file system. Use the API operation to monitor the status of the aliases Amazon FSx is disassociating with the file system.

    Args:
        client_request_token(str, optional): (Optional) An idempotency token for resource creation, in a string of up to 64 ASCII characters. This token is automatically filled on your behalf when you use the AWS Command Line Interface (AWS CLI) or an AWS SDK. Defaults to None.
        file_system_id(str): Specifies the file system from which to disassociate the DNS aliases.
        aliases(List): An array of one or more DNS alias names to disassociate, or remove, from the file system.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fsx.file_system.aliase.disassociate(
                ctx, file_system_id=value, aliases=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fsx.file_system.aliase.disassociate file_system_id=value, aliases=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fsx",
        operation="disassociate_file_system_aliases",
        op_kwargs={
            "ClientRequestToken": client_request_token,
            "FileSystemId": file_system_id,
            "Aliases": aliases,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, instance_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about one or more on-premises instances. The maximum number of on-premises instances that can be returned is 25.

    Args:
        instance_names(List): The names of the on-premises instances about which to get information. The maximum number of instance names you can specify is 25.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.get.on_premise_instance.batch(
                ctx, instance_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.get.on_premise_instance.batch instance_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="batch_get_on_premises_instances",
        op_kwargs={"instanceNames": instance_names},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def claim(hub, ctx, claim_code: str) -> Dict:
    r"""
    **Autogenerated function**

    Adds device(s) to your account (i.e., claim one or more devices) if and only if you
     received a claim code with the device(s).

    Args:
        claim_code(str): The claim code, starting with "C-", as provided by the device manufacturer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_device.device.by_claim_code.claim(
                ctx, claim_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_device.device.by_claim_code.claim claim_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-devices",
        operation="claim_devices_by_claim_code",
        op_kwargs={"ClaimCode": claim_code},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, wireless_gateway_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets operating information about a wireless gateway.

    Args:
        wireless_gateway_id(str): The ID of the wireless gateway for which to get the data.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.statistic.get_all(
                ctx, wireless_gateway_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.statistic.get_all wireless_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_wireless_gateway_statistics",
        op_kwargs={"WirelessGatewayId": wireless_gateway_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, endpoint_type: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a unique endpoint specific to the AWS account making the call.

    Args:
        endpoint_type(str, optional): The endpoint type. Valid endpoint types include:    iot:Data - Returns a VeriSign signed data endpoint.      iot:Data-ATS - Returns an ATS signed data endpoint.      iot:CredentialProvider - Returns an AWS IoT credentials provider API endpoint.      iot:Jobs - Returns an AWS IoT device management Jobs API endpoint.   We strongly recommend that customers use the newer iot:Data-ATS endpoint type to avoid issues related to the widespread distrust of Symantec certificate authorities. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.endpoint.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.endpoint.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_endpoint",
        op_kwargs={"endpointType": endpoint_type},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    cluster_identifier: str,
    database: str,
    sqls: List,
    db_user: str = None,
    secret_arn: str = None,
    statement_name: str = None,
    with_event: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Runs one or more SQL statements, which can be data manipulation language (DML) or data definition language (DDL). Depending on the authorization method, use one of the following combinations of request parameters:    Secrets Manager - specify the Amazon Resource Name (ARN) of the secret, the database name, and the cluster identifier that matches the cluster in the secret.    Temporary credentials - specify the cluster identifier, the database name, and the database user name. Permission to call the redshift:GetClusterCredentials operation is required to use this method.

    Args:
        cluster_identifier(str): The cluster identifier. This parameter is required when authenticating using either Secrets Manager or temporary credentials. .
        database(str): The name of the database. This parameter is required when authenticating using either Secrets Manager or temporary credentials. .
        db_user(str, optional): The database user name. This parameter is required when authenticating using temporary credentials. . Defaults to None.
        secret_arn(str, optional): The name or ARN of the secret that enables access to the database. This parameter is required when authenticating using Secrets Manager. . Defaults to None.
        sqls(List): One or more SQL statements to run. .
        statement_name(str, optional): The name of the SQL statements. You can name the SQL statements when you create them to identify the query. . Defaults to None.
        with_event(bool, optional): A value that indicates whether to send an event to the Amazon EventBridge event bus after the SQL statements run. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift_data.execute_statement.batch(
                ctx, cluster_identifier=value, database=value, sqls=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift_data.execute_statement.batch cluster_identifier=value, database=value, sqls=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift-data",
        operation="batch_execute_statement",
        op_kwargs={
            "ClusterIdentifier": cluster_identifier,
            "Database": database,
            "DbUser": db_user,
            "SecretArn": secret_arn,
            "Sqls": sqls,
            "StatementName": statement_name,
            "WithEvent": with_event,
        },
    )
